pub struct KmsCtx<'scope> { /* private fields */ }Expand description
Manages a single KMS HTTP request/response.
Implementations
Sourceimpl<'scope> KmsCtx<'scope>
impl<'scope> KmsCtx<'scope>
Sourcepub fn endpoint(&self) -> Result<&'scope str>
pub fn endpoint(&self) -> Result<&'scope str>
Get the hostname from which to connect over TLS.
The endpoint consists of a hostname and port separated by a colon. E.g. “example.com:123”. A port is always present.
Sourcepub fn sleep_micros(&self) -> i64
pub fn sleep_micros(&self) -> i64
How many microseconds to sleep before sending a request.
Sourcepub fn retry_failure(&self) -> bool
pub fn retry_failure(&self) -> bool
Whether a failed request can be retried.
Sourcepub fn bytes_needed(&self) -> u32
pub fn bytes_needed(&self) -> u32
Indicates how many bytes to feed into feed.
Sourcepub fn feed(&mut self, bytes: &[u8]) -> Result<()>
pub fn feed(&mut self, bytes: &[u8]) -> Result<()>
Feed bytes from the HTTP response.
Feeding more bytes than what has been returned in bytes_needed is an error.
Sourcepub fn feed_with_retry(&mut self, bytes: &[u8]) -> Result<bool>
pub fn feed_with_retry(&mut self, bytes: &[u8]) -> Result<bool>
Feed bytes from the HTTP response. Returns true if the KMS request should be retried.
Feeding more bytes than what has been returned in bytes_needed is an error.
Sourcepub fn kms_provider(&self) -> Result<KmsProvider>
pub fn kms_provider(&self) -> Result<KmsProvider>
Get the KMS provider identifier associated with this KMS request.
This is used to conditionally configure TLS connections based on the KMS request. It is useful for KMIP, which authenticates with a client certificate.